define(
//begin v1.x content
({
	"findLabel": "Sök:",
	"findTooltip": "Ange den text du vill söka efter",
	"replaceLabel": "Ersätt med:",
	"replaceTooltip": "Ange den text du vill ersätta med",
	"findReplace": "Sök och ersätt",
	"matchCase": "Matcha skiftläge",
	"matchCaseTooltip": "Matcha skiftläge",
	"backwards": "Bakåt",
	"backwardsTooltip": "Sök bakåt efter text",
	"replaceAllButton": "Ersätt alla",
	"replaceAllButtonTooltip": "Ersätt all text",
	"findButton": "Sök",
	"findButtonTooltip": "Sök efter texten",
	"replaceButton": "Ersätt",
	"replaceButtonTooltip": "Ersätt texten",
	"replaceDialogText": "${0} förekomster ersattes.",
	"eofDialogText": "Senaste förekomst${0}",
	"eofDialogTextFind": "hittades",
	"eofDialogTextReplace": "ersattes"
})

//end v1.x content
);
